Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTikrServer(s grpc.ServiceRegistrar, srv TikrServer)
- type BarData
- func (*BarData) Descriptor() ([]byte, []int)deprecated
- func (x *BarData) GetBucketTs() uint64
- func (x *BarData) GetDimensions() map[string]string
- func (x *BarData) GetFirstTimestamp() uint64
- func (x *BarData) GetLastTimestamp() uint64
- func (x *BarData) GetMetrics() map[string]int64
- func (x *BarData) GetSeries() string
- func (x *BarData) GetTickCount() uint64
- func (*BarData) ProtoMessage()
- func (x *BarData) ProtoReflect() protoreflect.Message
- func (x *BarData) Reset()
- func (x *BarData) String() string
- type BarQuery
- func (*BarQuery) Descriptor() ([]byte, []int)deprecated
- func (x *BarQuery) GetDimensions() map[string]string
- func (x *BarQuery) GetEndNs() uint64
- func (x *BarQuery) GetSeries() string
- func (x *BarQuery) GetStartNs() uint64
- func (*BarQuery) ProtoMessage()
- func (x *BarQuery) ProtoReflect() protoreflect.Message
- func (x *BarQuery) Reset()
- func (x *BarQuery) String() string
- type Empty
- type IngestRequest
- func (*IngestRequest) Descriptor() ([]byte, []int)deprecated
- func (x *IngestRequest) GetSeries() string
- func (x *IngestRequest) GetTicks() []*TickData
- func (*IngestRequest) ProtoMessage()
- func (x *IngestRequest) ProtoReflect() protoreflect.Message
- func (x *IngestRequest) Reset()
- func (x *IngestRequest) String() string
- type IngestResponse
- type SeriesInfo
- func (*SeriesInfo) Descriptor() ([]byte, []int)deprecated
- func (x *SeriesInfo) GetDimensions() []string
- func (x *SeriesInfo) GetMetrics() []string
- func (x *SeriesInfo) GetName() string
- func (x *SeriesInfo) GetRollup() string
- func (*SeriesInfo) ProtoMessage()
- func (x *SeriesInfo) ProtoReflect() protoreflect.Message
- func (x *SeriesInfo) Reset()
- func (x *SeriesInfo) String() string
- type SeriesList
- type ServerInfo
- func (*ServerInfo) Descriptor() ([]byte, []int)deprecated
- func (x *ServerInfo) GetSeries() []*SeriesInfo
- func (x *ServerInfo) GetUptimeSeconds() uint64
- func (x *ServerInfo) GetVersion() string
- func (*ServerInfo) ProtoMessage()
- func (x *ServerInfo) ProtoReflect() protoreflect.Message
- func (x *ServerInfo) Reset()
- func (x *ServerInfo) String() string
- type TickData
- func (*TickData) Descriptor() ([]byte, []int)deprecated
- func (x *TickData) GetDimensions() map[string]string
- func (x *TickData) GetFields() map[string]int64
- func (x *TickData) GetSequence() uint32
- func (x *TickData) GetTimestampNs() uint64
- func (*TickData) ProtoMessage()
- func (x *TickData) ProtoReflect() protoreflect.Message
- func (x *TickData) Reset()
- func (x *TickData) String() string
- type TickQuery
- func (*TickQuery) Descriptor() ([]byte, []int)deprecated
- func (x *TickQuery) GetDimensions() map[string]string
- func (x *TickQuery) GetEndNs() uint64
- func (x *TickQuery) GetLimit() uint32
- func (x *TickQuery) GetSeries() string
- func (x *TickQuery) GetStartNs() uint64
- func (*TickQuery) ProtoMessage()
- func (x *TickQuery) ProtoReflect() protoreflect.Message
- func (x *TickQuery) Reset()
- func (x *TickQuery) String() string
- type TikrClient
- type TikrServer
- type Tikr_IngestTicksClient
- type Tikr_IngestTicksServer
- type Tikr_QueryBarsClient
- type Tikr_QueryBarsServer
- type Tikr_QueryTicksClient
- type Tikr_QueryTicksServer
- type UnimplementedTikrServer
- func (UnimplementedTikrServer) GetInfo(context.Context, *Empty) (*ServerInfo, error)
- func (UnimplementedTikrServer) IngestTicks(grpc.ClientStreamingServer[IngestRequest, IngestResponse]) error
- func (UnimplementedTikrServer) ListSeries(context.Context, *Empty) (*SeriesList, error)
- func (UnimplementedTikrServer) QueryBars(*BarQuery, grpc.ServerStreamingServer[BarData]) error
- func (UnimplementedTikrServer) QueryTicks(*TickQuery, grpc.ServerStreamingServer[TickData]) error
- type UnsafeTikrServer
Constants ¶
const ( Tikr_IngestTicks_FullMethodName = "/tikr.v1.Tikr/IngestTicks" Tikr_QueryTicks_FullMethodName = "/tikr.v1.Tikr/QueryTicks" Tikr_QueryBars_FullMethodName = "/tikr.v1.Tikr/QueryBars" Tikr_ListSeries_FullMethodName = "/tikr.v1.Tikr/ListSeries" Tikr_GetInfo_FullMethodName = "/tikr.v1.Tikr/GetInfo" )
Variables ¶
var File_tikr_proto protoreflect.FileDescriptor
var Tikr_ServiceDesc = grpc.ServiceDesc{ ServiceName: "tikr.v1.Tikr", HandlerType: (*TikrServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListSeries", Handler: _Tikr_ListSeries_Handler, }, { MethodName: "GetInfo", Handler: _Tikr_GetInfo_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "IngestTicks", Handler: _Tikr_IngestTicks_Handler, ClientStreams: true, }, { StreamName: "QueryTicks", Handler: _Tikr_QueryTicks_Handler, ServerStreams: true, }, { StreamName: "QueryBars", Handler: _Tikr_QueryBars_Handler, ServerStreams: true, }, }, Metadata: "tikr.proto", }
Tikr_ServiceDesc is the grpc.ServiceDesc for Tikr service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTikrServer ¶
func RegisterTikrServer(s grpc.ServiceRegistrar, srv TikrServer)
Types ¶
type BarData ¶
type BarData struct {
Series string `protobuf:"bytes,1,opt,name=series,proto3" json:"series,omitempty"`
BucketTs uint64 `protobuf:"varint,2,opt,name=bucket_ts,json=bucketTs,proto3" json:"bucket_ts,omitempty"`
Dimensions map[string]string `` /* 147-byte string literal not displayed */
Metrics map[string]int64 `` /* 142-byte string literal not displayed */
FirstTimestamp uint64 `protobuf:"varint,5,opt,name=first_timestamp,json=firstTimestamp,proto3" json:"first_timestamp,omitempty"`
LastTimestamp uint64 `protobuf:"varint,6,opt,name=last_timestamp,json=lastTimestamp,proto3" json:"last_timestamp,omitempty"`
TickCount uint64 `protobuf:"varint,7,opt,name=tick_count,json=tickCount,proto3" json:"tick_count,omitempty"`
// contains filtered or unexported fields
}
func (*BarData) Descriptor
deprecated
func (*BarData) GetBucketTs ¶
func (*BarData) GetDimensions ¶
func (*BarData) GetFirstTimestamp ¶
func (*BarData) GetLastTimestamp ¶
func (*BarData) GetMetrics ¶
func (*BarData) GetTickCount ¶
func (*BarData) ProtoMessage ¶
func (*BarData) ProtoMessage()
func (*BarData) ProtoReflect ¶
func (x *BarData) ProtoReflect() protoreflect.Message
type BarQuery ¶
type BarQuery struct {
Series string `protobuf:"bytes,1,opt,name=series,proto3" json:"series,omitempty"`
Dimensions map[string]string `` /* 147-byte string literal not displayed */
StartNs uint64 `protobuf:"varint,3,opt,name=start_ns,json=startNs,proto3" json:"start_ns,omitempty"`
EndNs uint64 `protobuf:"varint,4,opt,name=end_ns,json=endNs,proto3" json:"end_ns,omitempty"`
// contains filtered or unexported fields
}
func (*BarQuery) Descriptor
deprecated
func (*BarQuery) GetDimensions ¶
func (*BarQuery) GetStartNs ¶
func (*BarQuery) ProtoMessage ¶
func (*BarQuery) ProtoMessage()
func (*BarQuery) ProtoReflect ¶
func (x *BarQuery) ProtoReflect() protoreflect.Message
type Empty ¶
type Empty struct {
// contains filtered or unexported fields
}
func (*Empty) Descriptor
deprecated
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) ProtoReflect ¶
func (x *Empty) ProtoReflect() protoreflect.Message
type IngestRequest ¶
type IngestRequest struct {
Series string `protobuf:"bytes,1,opt,name=series,proto3" json:"series,omitempty"`
Ticks []*TickData `protobuf:"bytes,2,rep,name=ticks,proto3" json:"ticks,omitempty"`
// contains filtered or unexported fields
}
func (*IngestRequest) Descriptor
deprecated
func (*IngestRequest) Descriptor() ([]byte, []int)
Deprecated: Use IngestRequest.ProtoReflect.Descriptor instead.
func (*IngestRequest) GetSeries ¶
func (x *IngestRequest) GetSeries() string
func (*IngestRequest) GetTicks ¶
func (x *IngestRequest) GetTicks() []*TickData
func (*IngestRequest) ProtoMessage ¶
func (*IngestRequest) ProtoMessage()
func (*IngestRequest) ProtoReflect ¶
func (x *IngestRequest) ProtoReflect() protoreflect.Message
func (*IngestRequest) Reset ¶
func (x *IngestRequest) Reset()
func (*IngestRequest) String ¶
func (x *IngestRequest) String() string
type IngestResponse ¶
type IngestResponse struct {
TicksReceived uint64 `protobuf:"varint,1,opt,name=ticks_received,json=ticksReceived,proto3" json:"ticks_received,omitempty"`
// contains filtered or unexported fields
}
func (*IngestResponse) Descriptor
deprecated
func (*IngestResponse) Descriptor() ([]byte, []int)
Deprecated: Use IngestResponse.ProtoReflect.Descriptor instead.
func (*IngestResponse) GetTicksReceived ¶
func (x *IngestResponse) GetTicksReceived() uint64
func (*IngestResponse) ProtoMessage ¶
func (*IngestResponse) ProtoMessage()
func (*IngestResponse) ProtoReflect ¶
func (x *IngestResponse) ProtoReflect() protoreflect.Message
func (*IngestResponse) Reset ¶
func (x *IngestResponse) Reset()
func (*IngestResponse) String ¶
func (x *IngestResponse) String() string
type SeriesInfo ¶
type SeriesInfo struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Dimensions []string `protobuf:"bytes,2,rep,name=dimensions,proto3" json:"dimensions,omitempty"`
Metrics []string `protobuf:"bytes,3,rep,name=metrics,proto3" json:"metrics,omitempty"`
Rollup string `protobuf:"bytes,4,opt,name=rollup,proto3" json:"rollup,omitempty"`
// contains filtered or unexported fields
}
func (*SeriesInfo) Descriptor
deprecated
func (*SeriesInfo) Descriptor() ([]byte, []int)
Deprecated: Use SeriesInfo.ProtoReflect.Descriptor instead.
func (*SeriesInfo) GetDimensions ¶
func (x *SeriesInfo) GetDimensions() []string
func (*SeriesInfo) GetMetrics ¶
func (x *SeriesInfo) GetMetrics() []string
func (*SeriesInfo) GetName ¶
func (x *SeriesInfo) GetName() string
func (*SeriesInfo) GetRollup ¶
func (x *SeriesInfo) GetRollup() string
func (*SeriesInfo) ProtoMessage ¶
func (*SeriesInfo) ProtoMessage()
func (*SeriesInfo) ProtoReflect ¶
func (x *SeriesInfo) ProtoReflect() protoreflect.Message
func (*SeriesInfo) Reset ¶
func (x *SeriesInfo) Reset()
func (*SeriesInfo) String ¶
func (x *SeriesInfo) String() string
type SeriesList ¶
type SeriesList struct {
Series []*SeriesInfo `protobuf:"bytes,1,rep,name=series,proto3" json:"series,omitempty"`
// contains filtered or unexported fields
}
func (*SeriesList) Descriptor
deprecated
func (*SeriesList) Descriptor() ([]byte, []int)
Deprecated: Use SeriesList.ProtoReflect.Descriptor instead.
func (*SeriesList) GetSeries ¶
func (x *SeriesList) GetSeries() []*SeriesInfo
func (*SeriesList) ProtoMessage ¶
func (*SeriesList) ProtoMessage()
func (*SeriesList) ProtoReflect ¶
func (x *SeriesList) ProtoReflect() protoreflect.Message
func (*SeriesList) Reset ¶
func (x *SeriesList) Reset()
func (*SeriesList) String ¶
func (x *SeriesList) String() string
type ServerInfo ¶
type ServerInfo struct {
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
UptimeSeconds uint64 `protobuf:"varint,2,opt,name=uptime_seconds,json=uptimeSeconds,proto3" json:"uptime_seconds,omitempty"`
Series []*SeriesInfo `protobuf:"bytes,3,rep,name=series,proto3" json:"series,omitempty"`
// contains filtered or unexported fields
}
func (*ServerInfo) Descriptor
deprecated
func (*ServerInfo) Descriptor() ([]byte, []int)
Deprecated: Use ServerInfo.ProtoReflect.Descriptor instead.
func (*ServerInfo) GetSeries ¶
func (x *ServerInfo) GetSeries() []*SeriesInfo
func (*ServerInfo) GetUptimeSeconds ¶
func (x *ServerInfo) GetUptimeSeconds() uint64
func (*ServerInfo) GetVersion ¶
func (x *ServerInfo) GetVersion() string
func (*ServerInfo) ProtoMessage ¶
func (*ServerInfo) ProtoMessage()
func (*ServerInfo) ProtoReflect ¶
func (x *ServerInfo) ProtoReflect() protoreflect.Message
func (*ServerInfo) Reset ¶
func (x *ServerInfo) Reset()
func (*ServerInfo) String ¶
func (x *ServerInfo) String() string
type TickData ¶
type TickData struct {
TimestampNs uint64 `protobuf:"varint,1,opt,name=timestamp_ns,json=timestampNs,proto3" json:"timestamp_ns,omitempty"`
Dimensions map[string]string `` /* 147-byte string literal not displayed */
Fields map[string]int64 `` /* 140-byte string literal not displayed */
Sequence uint32 `protobuf:"varint,4,opt,name=sequence,proto3" json:"sequence,omitempty"`
// contains filtered or unexported fields
}
func (*TickData) Descriptor
deprecated
func (*TickData) GetDimensions ¶
func (*TickData) GetSequence ¶
func (*TickData) GetTimestampNs ¶
func (*TickData) ProtoMessage ¶
func (*TickData) ProtoMessage()
func (*TickData) ProtoReflect ¶
func (x *TickData) ProtoReflect() protoreflect.Message
type TickQuery ¶
type TickQuery struct {
Series string `protobuf:"bytes,1,opt,name=series,proto3" json:"series,omitempty"`
Dimensions map[string]string `` /* 147-byte string literal not displayed */
StartNs uint64 `protobuf:"varint,3,opt,name=start_ns,json=startNs,proto3" json:"start_ns,omitempty"`
EndNs uint64 `protobuf:"varint,4,opt,name=end_ns,json=endNs,proto3" json:"end_ns,omitempty"`
Limit uint32 `protobuf:"varint,5,opt,name=limit,proto3" json:"limit,omitempty"`
// contains filtered or unexported fields
}
func (*TickQuery) Descriptor
deprecated
func (*TickQuery) GetDimensions ¶
func (*TickQuery) GetStartNs ¶
func (*TickQuery) ProtoMessage ¶
func (*TickQuery) ProtoMessage()
func (*TickQuery) ProtoReflect ¶
func (x *TickQuery) ProtoReflect() protoreflect.Message
type TikrClient ¶
type TikrClient interface {
// Streaming ingest — client sends a stream of IngestRequests.
IngestTicks(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[IngestRequest, IngestResponse], error)
// Query raw ticks in a time range.
QueryTicks(ctx context.Context, in *TickQuery, opts ...grpc.CallOption) (grpc.ServerStreamingClient[TickData], error)
// Query rolled-up bars in a time range.
QueryBars(ctx context.Context, in *BarQuery, opts ...grpc.CallOption) (grpc.ServerStreamingClient[BarData], error)
// List all configured series.
ListSeries(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*SeriesList, error)
// Get server info.
GetInfo(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*ServerInfo, error)
}
TikrClient is the client API for Tikr service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTikrClient ¶
func NewTikrClient(cc grpc.ClientConnInterface) TikrClient
type TikrServer ¶
type TikrServer interface {
// Streaming ingest — client sends a stream of IngestRequests.
IngestTicks(grpc.ClientStreamingServer[IngestRequest, IngestResponse]) error
// Query raw ticks in a time range.
QueryTicks(*TickQuery, grpc.ServerStreamingServer[TickData]) error
// Query rolled-up bars in a time range.
QueryBars(*BarQuery, grpc.ServerStreamingServer[BarData]) error
// List all configured series.
ListSeries(context.Context, *Empty) (*SeriesList, error)
// Get server info.
GetInfo(context.Context, *Empty) (*ServerInfo, error)
// contains filtered or unexported methods
}
TikrServer is the server API for Tikr service. All implementations must embed UnimplementedTikrServer for forward compatibility.
type Tikr_IngestTicksClient ¶
type Tikr_IngestTicksClient = grpc.ClientStreamingClient[IngestRequest, IngestResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Tikr_IngestTicksServer ¶
type Tikr_IngestTicksServer = grpc.ClientStreamingServer[IngestRequest, IngestResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Tikr_QueryBarsClient ¶
type Tikr_QueryBarsClient = grpc.ServerStreamingClient[BarData]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Tikr_QueryBarsServer ¶
type Tikr_QueryBarsServer = grpc.ServerStreamingServer[BarData]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Tikr_QueryTicksClient ¶
type Tikr_QueryTicksClient = grpc.ServerStreamingClient[TickData]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Tikr_QueryTicksServer ¶
type Tikr_QueryTicksServer = grpc.ServerStreamingServer[TickData]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTikrServer ¶
type UnimplementedTikrServer struct{}
UnimplementedTikrServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTikrServer) GetInfo ¶
func (UnimplementedTikrServer) GetInfo(context.Context, *Empty) (*ServerInfo, error)
func (UnimplementedTikrServer) IngestTicks ¶
func (UnimplementedTikrServer) IngestTicks(grpc.ClientStreamingServer[IngestRequest, IngestResponse]) error
func (UnimplementedTikrServer) ListSeries ¶
func (UnimplementedTikrServer) ListSeries(context.Context, *Empty) (*SeriesList, error)
func (UnimplementedTikrServer) QueryBars ¶
func (UnimplementedTikrServer) QueryBars(*BarQuery, grpc.ServerStreamingServer[BarData]) error
func (UnimplementedTikrServer) QueryTicks ¶
func (UnimplementedTikrServer) QueryTicks(*TickQuery, grpc.ServerStreamingServer[TickData]) error
type UnsafeTikrServer ¶
type UnsafeTikrServer interface {
// contains filtered or unexported methods
}
UnsafeTikrServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TikrServer will result in compilation errors.